From f73b655466092169abac34833fb628fce1fcdebe Mon Sep 17 00:00:00 2001
From: jcduff <jcduff@localhost>
Date: Thu, 23 Oct 2008 14:04:24 +0000
Subject: [PATCH] The commit will bring the following features :     - An updated version of the underlying database. BDB JE 3.3 is now used.     - Attribute API refactoring providing a better abstraction and offering improved performances.     - A new GUI called the Control-Panel to replace the Status-Panel: the specifications for this       GUI are available on OpenDS Wiki and contains a link to a mockup.        See <https://www.opends.org/wiki/page/ControlPanelUISpecification>.     - Some changes in the replication protocol to implement "Assured Replication Mode". The        specifications are on OpenDS Wiki at <https://www.opends.org/wiki/page/AssuredMode> and section 7       described some of the replication changes required to support this. Assured Replication is not finished,       but the main replication protocol changes to support it are done. As explained by Gilles on an email on       the Dev mailing list (http://markmail.org/message/46rgo3meq3vriy4a), with these changes the newer versions       of OpenDS may not be able to replicate with OpenDS 1.0 instances.     - Support for Service Tags on the platforms where the functionality is available and enabled. Specifications       are published at <https://www.opends.org/wiki/page/OpenDSServiceTagEnabled>. For more information on       Service Tags see <http://wikis.sun.com/display/ServiceTag/Sun+Service+Tag+FAQ>.     - The Admin Connector service. In order to provide agentry of the OpenDS server at any time, a new service       has been added, dedicated to the administration, configuration and monitoring of the server.       An overview of the Admin Connector service and it's use is available on the       OpenDS wiki <https://www.opends.org/wiki/page/ManagingAdministrationTrafficToTheServer>     - Updates to the various command line tools to support the Admin Connector service.     - Some internal re-architecting of the server to put the foundation of future developments such as virtual       directory services. The new NetworkGroups and WorkFlow internal services which have been specified in       <https://www.opends.org/wiki/page/BasicOperationRoutingThroughNetworkGroup> are now implemented.     - Many bug fixes...

---
 opends/src/server/org/opends/server/replication/plugin/PendingChanges.java |   24 ++++++++++++------------
 1 files changed, 12 insertions(+), 12 deletions(-)

diff --git a/opends/src/server/org/opends/server/replication/plugin/PendingChanges.java b/opends/src/server/org/opends/server/replication/plugin/PendingChanges.java
index 46b73b0..513e41c 100644
--- a/opends/src/server/org/opends/server/replication/plugin/PendingChanges.java
+++ b/opends/src/server/org/opends/server/replication/plugin/PendingChanges.java
@@ -33,18 +33,18 @@
 import org.opends.server.replication.common.ChangeNumber;
 import org.opends.server.replication.common.ChangeNumberGenerator;
 import org.opends.server.replication.common.ServerState;
-import org.opends.server.replication.protocol.UpdateMessage;
+import org.opends.server.replication.protocol.UpdateMsg;
 import org.opends.server.types.operation.PluginOperation;
 
 /**
- * This class is use to store the list of local operations currently
+ * This class is used to store the list of local operations currently
  * in progress and not yet committed in the database.
  *
  * It is used to make sure that operations are sent to the Replication
  * Server in the order defined by their ChangeNumber.
  * It is also used to update the ServerState at the appropriate time.
  *
- * On object of this class is instanciated for each ReplicationDomain.
+ * On object of this class is instantiated for each ReplicationDomain.
  */
 public class PendingChanges
 {
@@ -61,12 +61,12 @@
   private ChangeNumberGenerator changeNumberGenerator;
 
   /**
    * The Replicationbroker that will be used to send UpdateMessage.
    */
   private ReplicationBroker broker;
 
   /**
-   * The ServerState that will be updated when UpdateMessage are committed.
+   * The ServerState that will be updated when UpdateMsg are committed.
    */
   private ServerState state;
 
@@ -76,8 +76,8 @@
    * @param changeNumberGenerator The ChangeNumberGenerator to use to create
    *                               new unique ChangeNumbers.
    * @param broker  The Replicationbroker that will be used to send
-   *                UpdateMessage.
-   * @param state   The ServerState that will be updated when UpdateMessage
+   *                UpdateMsg.
+   * @param state   The ServerState that will be updated when UpdateMsg
    *                are committed.
    */
   public PendingChanges(
@@ -94,9 +94,9 @@
    *
    * @param changeNumber The ChangeNumber of the update to remove.
    *
    * @return The UpdateMessage that was just removed.
    */
-  public synchronized UpdateMessage remove(ChangeNumber changeNumber)
+  public synchronized UpdateMsg remove(ChangeNumber changeNumber)
   {
     return pendingChanges.remove(changeNumber).getMsg();
   }
@@ -119,7 +119,7 @@
    * @param msg          The message associated to the update.
    */
   public synchronized void commit(ChangeNumber changeNumber,
-      UpdateMessage msg)
+      UpdateMsg msg)
   {
     PendingChange curChange = pendingChanges.get(changeNumber);
     if (curChange == null)
@@ -148,10 +148,10 @@
   }
 
   /**
    * Add a new UpdateMessage to the pending list from the provided local
    * operation.
    *
    * @param operation The local operation for which an UpdateMessage mus
    *                  be added in the pending list.
    * @return The ChangeNumber now associated to the operation.
    */
@@ -61,12 +61,12 @@
 
   /**
-   * The Replicationbroker that will be used to send UpdateMessage.
+   * The Replicationbroker that will be used to send UpdateMsg.
    */
   private ReplicationBroker broker;
@@ -94,9 +94,9 @@
    * @param changeNumber The ChangeNumber of the update to remove.
    *
-   * @return The UpdateMessage that was just removed.
+   * @return The UpdateMsg that was just removed.
    */
@@ -148,10 +148,10 @@
 
   /**
-   * Add a new UpdateMessage to the pending list from the provided local
+   * Add a new UpdateMsg to the pending list from the provided local
    * operation.
    *
@@ -148,10 +148,10 @@
    * operation.
    *
-   * @param operation The local operation for which an UpdateMessage mus
+   * @param operation The local operation for which an UpdateMsg must
    *                  be added in the pending list.
    * @return The ChangeNumber now associated to the operation.

--
Gitblit v1.10.0